@@ -10,7 +10,6 @@
 
 require 'sync'
 require 'delegate'
-require 'amstd/to_s'
 require 'tmail/parsemail'
 require 'tmail/encode'
 
@@ -145,8 +144,8 @@ module TMail
       end
 
       def header_attr( name, type, flags, ali = nil, add = '' )
-        name = _name2str( name )
-        type = _type2str( type )
+        name = name.to_s
+        # arg 'type' not use
         r = (flags & R != 0)
         w = (flags & W != 0)
         c = (flags & NODUP != 0)
@@ -181,9 +180,8 @@ module TMail
 
         if ali then
           ali.each do |a|
-            na = _name2str( a )
-            module_eval %(alias #{na} #{name})
-            module_eval %(alias #{na}= #{name}=) if w
+            module_eval %(alias #{a} #{name})
+            module_eval %(alias #{a}= #{name}=) if w
           end
         end
       end
